@@ -301,10 +301,6 @@ class VortexTcpConnectTest(unittest.TestCase,
     def test_vortexReconnect100(self):
         yield self.__vortexReconnect(100)
 
-    @inlineCallbacks
-    def test_vortexReconnect500(self):
-        yield self.__vortexReconnect(500)
-
     @inlineCallbacks
     def __vortexReconnect_with_data(self, count):
         self._memMark()
@@ -321,10 +317,6 @@ class VortexTcpConnectTest(unittest.TestCase,
     def test_vortexReconnect100_with_data(self):
         yield self.__vortexReconnect_with_data(100)
 
-    @inlineCallbacks
-    def test_vortexReconnect500_with_data(self):
-        yield self.__vortexReconnect_with_data(500)
-
 
 class VortexTcpMemoryLeakTest(unittest.TestCase,
                               MemoryCheckerTestMixin,
@@ -535,22 +527,6 @@ class VortexTcpMemoryLeakLargeTransfersTest(unittest.TestCase,
     def test_2vortexSend1gb_compression1(self):
         yield self.__vortexSendTest(1024 ** 3, compression=1)
 
-    @inlineCallbacks
-    def test_2vortexSend1gb_compression9(self):
-        yield self.__vortexSendTest(1024 ** 3, compression=9)
-
     @inlineCallbacks
     def test_3vortexSend3gb_compression1(self):
         yield self.__vortexSendTest(1024 ** 3 * 3, compression=1)
-
-    @inlineCallbacks
-    def test_3vortexSend3gb_compression9(self):
-        yield self.__vortexSendTest(1024 ** 3 * 3, compression=9)
-
-    @inlineCallbacks
-    def test_4vortexSend10gb_compression1(self):
-        yield self.__vortexSendTest(1024 ** 3 * 10, compression=1)
-
-    @inlineCallbacks
-    def test_4vortexSend10gb_compression9(self):
-        yield self.__vortexSendTest(1024 ** 3 * 10, compression=9)
